package org.puimula.experimental.solrtest;

import java.io.IOException;
import java.util.List;

import org.apache.lucene.analysis.TokenFilter;
import org.apache.lucene.analysis.TokenStream;
import org.apache.lucene.analysis.tokenattributes.CharTermAttribute;
import org.puimula.libvoikko.Analysis;
import org.puimula.libvoikko.Voikko;

public class VoikkoBaseformFilter extends TokenFilter {

	private static final String BASEFORM_ATTR = "BASEFORM";
	
	private final CharTermAttribute termAtt = addAttribute(CharTermAttribute.class);
	private final Voikko voikko = new Voikko("fi-x-morphoid");
	// FIXME: resource leak: should call voikko.terminate() at some point ...
	
	protected VoikkoBaseformFilter(TokenStream input) {
		super(input);
	}

	@Override
	public boolean incrementToken() throws IOException {
		if (input.incrementToken()) {
			String word = termAtt.toString();
			List<Analysis> analysisList = voikko.analyze(word);
			if (!analysisList.isEmpty())
			{
				// TODO: this will use only the first analysis
				Analysis analysis = analysisList.get(0);
				if (analysis.containsKey(BASEFORM_ATTR)) {
					termAtt.setEmpty();
					termAtt.append(analysis.get(BASEFORM_ATTR));
				}
			}
			return true;
		} else {
			return false;
		}
	}
	
}
